@@ -1,5 +1,5 @@
-fit.variogram<-function(type="exponential", ...){
-        switch(type,
+fit.variogram<-function(model="exponential", ...){
+        switch(model,
                exponential = fit.exponential(...),
                gaussian = fit.gaussian(...),
                wave = fit.wave(...),
